@@ -220,16 +220,11 @@ async def post_grade(solutions_base_path, metadata):
 
 
 class OtterHandler(HubOAuthenticated, tornado.web.RequestHandler):
-    @tornado.web.authenticated
-    def get(self):
-        log_tornado_issues('Authenticated?', "info")
+    async def get(self):
         self.write("This is a post only page. You probably shouldn't be here!")
         user = self.get_current_user()
-        log_tornado_issues('Got User', "info")
-        log_tornado_issues(json.dumps(user, indent=1, sort_keys=True), "info")
         self.write(json.dumps(user, indent=1, sort_keys=True))
 
-    @tornado.web.authenticated
     async def post(self):
         user = {}
         metadata = {
@@ -506,14 +501,12 @@ def start_server():
                 HubOAuthCallbackHandler
             )
         ],
-        {
-            "cookie_secret": os.urandom(32)
-        }
+        cookie_secret=os.urandom(32)
     )
 
     server = tornado.httpserver.HTTPServer(app)
     server.listen(10101)
-    log_tornado_issues('Server started:', "info")
+    log_tornado_issues('Server started', "info")
     signal.signal(signal.SIGTERM, partial(sig_handler, server))
     signal.signal(signal.SIGINT, partial(sig_handler, server))
 
